<?php
/*
Plugin Name: 2Checkout Payment Gateway
Description: Allows customers to use 2Checkout as a payment method in AppThemes Products.

AppThemes ID: 2checkout

Version: 1.1
Author: AppThemes
Author URI: http://appthemes.com
Text Domain: appthemes-2checkout
*/

add_action( 'init', 'appthemes_2ch_setup' );

$locale = apply_filters( 'plugin_locale', get_locale(), 'appthemes-2checkout' );
load_textdomain( 'appthemes-2checkout', WP_LANG_DIR . "/plugins/2checkout-$locale.mo" );

function appthemes_2ch_setup(){

	// Check for right version of Vantage
	if( ! current_theme_supports( 'app-payments' ) ){
		add_action( 'admin_notices', 'appthemes_2ch_display_version_warning' );
		return;
	}

	appthemes_2ch_add_currencies();

	require dirname(__FILE__) . '/2ch-gateway.php';
	appthemes_register_gateway( 'APP_2Checkout' );

}

function appthemes_2ch_display_version_warning(){

	$message = __( 'AppThemes 2Checkout Платежный шлюз может не работать.', 'appthemes-2checkout' );

	if( !current_theme_supports( 'app-payments' ) )
		$message = __( 'AppThemes 2Checkout Платежный шлюз не поддерживает текущую тему. Пожалуйста, используйте совместимый продукт AppThemes.', 'appthemes-2checkout' );

	echo '<div class="error fade"><p>' . $message .'</p></div>';
	deactivate_plugins( plugin_basename( __FILE__ ) );
}

class APP_2Checkout_Fields{
	const POST_URL = 'https://www.2checkout.com/checkout/purchase';
	const TEST_URL = 'https://sandbox.2checkout.com/checkout/purchase';
}

function appthemes_2ch_add_currencies(){

	$currencies = array(
		'ARS' => array(
			'symbol' => '$',
			'name' => __( 'Аргентинское песо', 'appthemes-2checkout' ),
		),
		'INR' => array(
			'name' => __( 'Indian Rupee', 'appthemes-2checkout' ),
		),
		'LTL' => array(
			'symbol' => 'Lt',
			'name' => __( 'Lithuanian Litas', 'appthemes-2checkout' ),
		),
		'RON' => array(
			'name' => __( 'Romanian Leu', 'appthemes-2checkout' ),
			'display' => '{price} {symbol}'
		),
		'RUB' => array(
			'name' => __( 'Российский рубль', 'appthemes-2checkout' ),
		),
		'ZAR' => array(
			'symbol' => 'R',
			'name' => __( 'South African Rand', 'appthemes-2checkout' ),
		),
		'AED' => array(
			'name' => __( 'United Arab Emirates Dirham', 'appthemes-2checkout' ),
		),
	);

	foreach( $currencies as $currency_code => $args )
		APP_Currencies::add_currency( $currency_code, $args );

}
