<?php

class APP_Graph_List extends WP_List_Table{

	protected $error = false;

	function setup_page_head(){

		wp_register_style( 'app-stats', plugins_url( 'style.css', __FILE__ ) );
		wp_enqueue_style( 'app-stats' );

		wp_enqueue_script( 'd3', plugins_url('includes/js/d3/d3.v2.js', __FILE__ ), true );
		wp_enqueue_script( 'app-stats', plugins_url('includes/js/main.js', __FILE__ ), true );

	}

	function prepare_items(){

		$args = array(
			'post_type' => $this->type->name,
			'nopaging' => true,
			'meta_query' => array()
		);

		$args = $this->prepare_query_vars( $args );

		$query = new WP_Query( $args );

		$this->query_vars = $args;
		$this->items = $query->posts;

		$this->parse_items();

	}

	function prepare_query_vars( $args ){

		$q = $_GET;

		$post_stati = get_post_stati();
		if ( isset($q['post_status']) && in_array( $q['post_status'], $post_stati ) ) {
			$args['post_status'] = $q['post_status'];
		}else{
			$args['post_status'] = 'any';
		}

		if( isset( $q['m'] ) ){
			$args['m'] = $q['m'];
		}

		return $args;

	}

	function display() {
		extract( $this->_args );

		$this->display_tablenav( 'top' );

		$this->display_graph();

		echo '<div style="clear:both;"></div>';

		$this->display_boxes();

		$this->display_tablenav( 'bottom' );
	}

	function display_graph(){

		if( $this->error == false ){
			echo '<svg id="app-stats-total" class="app-stats" style="width: 99%;height:300px;"></svg>';
		}
		else{
			echo scb_admin_notice( $this->error );
		}
	}

	function prepare_data( $data ){

		$totals = array();
		ksort( $data );
		foreach( $data as $time => $count ){
			$totals[] = array( 'time' => $time * 1000, 'count' => $count );
		}

		if( count( $totals ) <= 1 ){
			$this->error = __( 'Недостаточно данных для формирования графика.', 'appthemes-stats' );
			return false;
		}

		wp_localize_script( 'app-stats', 'stats', array( 'total' => $totals ) );
	}

	function display_boxes(){

		foreach( $this->get_stats_boxes() as $id ){
			$this->{$id . '_box' }();
		}

	}

	function statuses_dropdown(){

		$default = ( isset( $_GET['post_status'] ) ) ? $_GET['post_status'] : 'any';

		$options = html( 'option', array( 'value' => '' ), __( 'Показать все статусы', 'appthemes-stats' ) );
		foreach( appthemes_get_order_statuses() as $value => $string ){
			$args = array(
				'value' => $value
			);

			if( $default == $value )
				$args['selected'] = 'selected';

			$options .= html( 'option', $args, $string );
		}

		echo html( 'select', array( 'name' => 'post_status' ), $options );
	}

}