jQuery( function($){
    
    // Fix bug in firefox where .width() returns the percentage instead of calculated value
    if( $("#app-stats-total").width() == 99 && $("#app-stats-total").css("width") == "99%" ){
		$("#app-stats-total").width( $("#app-stats-total").parent().width() * .99 );
	}
    window.AppStats.totalViews.display( $("#app-stats-total"), window.stats.total );

} );
window.AppStats = {};
window.AppStats.totalViews = ( function( window ){

	var d3 = window.d3;

	var obj = {};
	var data;

	var container, graph, xScale, yScale;
	var metrics = {

		width : 0,
		height: 0,
		graphWidth : 0,
		graphHeight : 0,

		setup : function( element ){

			var $ = window.jQuery;

			metrics.width = $( element ).width();
			metrics.height = $( element ).height();

			metrics.graphHeight = metrics.height - 20;
			metrics.graphWidth = metrics.width - 20;
			metrics.graphWidth = metrics.graphWidth - metrics.barWidth();

			xScale = xScale.range( [0, metrics.graphWidth ] );
			yScale = yScale.range( [0, metrics.graphHeight ] );

		},

		barHeight : function( d, i ){
			return yScale( d.count );
		},

		barWidth : function(){
			return metrics.graphWidth / ( data.length );
		},

		barXPosition : function( d, i ){
			return xScale( new Date( d.time ) );
		},

		barYPosition : function( d, i ){
			if( d.count === undefined )
				d = { count : d };

			return metrics.graphHeight - metrics.barHeight( d, i );
		},
	}

	var formatter = d3.time.format( "%b %d %Y" );

	obj.display = function( element, input_data ) {

		data = input_data;
xScale
		 = getXScale();
		yScale = getYScale();

		container = d3.selectAll(element);
		metrics.setup( element );
	    
	    graph = container.append("g")
	    graph.attr("transform", "translate(20)scale(.99,1)");

	    displayGraph( graph );
	    displayAxis( container, graph );
	};

	function displayAxis( container, graph ){

	    graph.selectAll("text.time")
	    	.data( xScale.ticks( 8 ) )
	    	.enter().append("text")
	    		.attr( "class", "time" )
	    		.attr( "x", xScale )
	    		.attr( "y", metrics.graphHeight + 17 )
	    		.attr( "text-anchor", "middle")
	    		.attr( "dx", 4 )
	    		.text( formatter );

	    container.selectAll("text.count")
	    	.data( yScale.ticks( 5 ) )
	    	.enter().append("text")
	    		.attr( "class", "count" )
	    		.attr( "y", metrics.barYPosition )
	    		.attr( "x", 0 )
	    		.attr( "text-anchor", "start")
	    		.attr( "dx", 3 )
	    		.text(String);

	};

	function displayGraph( graph ){

		graph.selectAll("rect.data")
	    	.data(data, function(d){ return d.time; })
	    	.enter().append("rect")
	    		.attr("x", metrics.barXPosition )
	    		.attr("y", metrics.barYPosition  )
	    		.attr("height", metrics.barHeight )
	    		.attr("width", metrics.barWidth);

	    graph.selectAll("text.data-count")
	    	.data(data, function(d){ return d.time; })
	    	.enter().append("text")
	    		.attr("class", "data-count")
	    		.attr("x", metrics.barXPosition)
	    		.attr("y", metrics.graphHeight)
	    		.attr("dx", function( d, i ){ return metrics.barWidth( d, i ) / 2;})
	    		.attr("dy", -3)
	    		.attr("text-anchor", "middle")
	    		.text( function(d,i){ if( d.count != 0) return d.count; } );

	    graph.append("line")
	    	.attr( "class", "x-axis" )
	    	.attr( "x1", 0 )
	    	.attr( "x2", metrics.graphWidth + metrics.barWidth() )
	    	.attr( "y1", metrics.graphHeight + 2 )
	    	.attr( "y2", metrics.graphHeight + 2 );
	};

	function getYScale(){
		var max = d3.max( data, function(d,i){ return d.count; });
	    return d3.scale.linear().domain( [ 0 , max+2 ] );
	}

	function getXScale(){
		var max_date = new Date( data[ data.length-1 ].time );
    	var min_date = new Date( data[0].time );

		return d3.time.scale().domain( [ min_date, max_date ] );
	}

	return obj;

})( window );