<?php

class APP_Order_Stats_list extends APP_Graph_List{

	/**
	 * Post type object
	 * @var object
	 */
	public $type;

	/**
	 * Order stats object
	 * @var type APP_Order_Stat
	 */
	public $stat;

	function __construct(){

		$ptype = get_post_type_object( APPTHEMES_ORDER_PTYPE );
		$this->type = $ptype;

		parent::__construct( array(
			'ajax'     => false,
			'screen'   => null,
			'plural'   => $this->type->labels->name,
			'singular' => $this->type->labels->singular_name,
		) );


		$hidden_columns = array();
		$this->_column_headers = array(
			$this->get_columns(), $hidden_columns, $this->get_sortable_columns()
		);

	}

	function get_columns(){
		return array();
	}

	function get_bulk_actions(){
		return array();
	}

	function prepare_query_vars( $args ){

		$args = parent::prepare_query_vars( $args );

		$q = $_GET;

		if( !isset( $q['d'] ) ){
			$args['past_days'] = 90;
		}else{
			$args['past_days'] = intval( $q['d'] );
		}

		if( isset( $q['c'] ) && !empty( $q['c'] ) ){
			$args['meta_query'][] = array(
				'key' => 'currency',
				'value' => $q['c']
			);
		}

		if( isset( $q['g'] ) && !empty( $q['g'] ) ){
			$args['meta_query'][] = array(
				'key' => 'gateway',
				'value' => $q['g']
			);
		}

		return $args;

	}

	function parse_items(){

		$stats = new APP_Order_Stat( $this->items );
		$this->stat = $stats;

		foreach( array( APP_Stat::HOUR, APP_Stat::DAY, APP_Stat::MONTH) as $compression ){

			$this->compression = $compression;

			$counts = $this->stat->countDates( $compression );
			if( empty( $counts ) )
				break;

			$first = min( array_keys( $counts ) );
			$last = max( array_keys( $counts ) );
			$counts = $this->stat->expandCounts( $counts, $compression, $first, $last );
			if( count( $counts ) <= 180 ){
				break;
			}
		}

		$this->prepare_data( $counts );

	}

	function get_stats_boxes(){
		$boxes = array(
			'general',
			'meta',
			'income'
		);
		return $boxes;
	}

	function general_box(){

		if( count( $this->items ) == 0 )
			return;

		$all = appthemes_count_all_posts( APPTHEMES_ORDER_PTYPE );
		$total = count( $this->items );

		$first = $this->stat->firstDate();
		$last = $this->stat->lastDate();

		$days = count( $this->stat->dates() );

		$averages = array(
			'average' => $this->stat->countAverageByDate( $this->compression ),
			'median' => $this->stat->countMedianByDate( $this->compression ),
			'mode' => $this->stat->countModeByDate( $this->compression ),
		);

		$min = $this->stat->countMinByDate( $this->compression );
		$max = $this->stat->countMaxByDate( $this->compression );

		$filters = array();
		if( ! empty( $_GET['g'] ) )
			$filters[] = APP_Gateway_Registry::get_gateway( $_GET['g'] )->display_name( 'admin' );

		if( ! empty( $_GET['c'] ) )
			$filters[] = APP_Currencies::get_name( $_GET['c'] );

		?>
		<table class="widefat" style="width: 25%; float: left; clear: none; margin-right: 20px;">
			<tbody>
				<tr>
					<th colspan="2">В Настоящее Время Просмотров</th>
				</tr>
				<tr>
					<td>Значение типа timespan</td>
					<td><?php echo date( 'F jS Y', $first); ?> - <?php echo date( 'F jS Y', $last); ?></td>
				</tr>
				<tr>
					<td>Длина</td>
					<td><?php echo $days; ?> дней</td>
				</tr>
				<tr>
					<td>Фильтрация По</td>
					<td><?php echo join( ', ', $filters ); ?></td>
				</tr>
				<tr>
					<td>Данные</td>
					<td><?php echo $total; ?> продаж</td>
				</tr>
				<tr>
					<td>Viewport</td>
					<td><?php appthemes_display_percentage( $total, $all ); ?> of <?php echo $all; ?> total</td>
				</tr>
				<tr>
					<th colspan="2">Краткая Статистика</th>
				</tr>
				<tr>
					<td>Средняя</td>
					<td><?php echo round( $averages['average'], 2); ?> <em>(Median: <?php echo $averages['median']; ?>, Mode: <?php echo $averages['mode']; ?>)</em></td>
				</tr>
				<tr>
					<td>Высокие</td>
					<td><?php echo date( 'F jS Y', $max['date']); ?> (<?php echo $max['value']; ?> продажи)</td>
				</tr>
				<tr>
					<td>Низкие</td>
					<td><?php echo date( 'F jS Y', $min['date']); ?> (<?php echo $min['value']; ?> продажи)</td>
				</tr>
			</tbody>
		</table>
		<?php

	}

	function meta_box(){

		if( count( $this->items ) == 0 )
			return;

		$sales = array(
			'total' => count( $this->items ),
			'statuses' => $this->stat->countStatuses(),
			'gateways' => $this->stat->countGateways(),
			'currencies' => $this->stat->countCurrencies(),
		);

		?>
		<table class="widefat" style="width: 25%; float: left; clear: none; margin-right: 20px;">
			<tbody>
				<tr>
					<th colspan="3">Статусы</th>
				</tr>
			<?php foreach( appthemes_get_order_statuses() as $status => $string ){
					$stat = ( isset( $sales['statuses'][ $status ] ) ) ? $sales['statuses'][ $status ] : 0;
			?>
				<tr>
					<td><?php echo $string; ?></td>
					<td><?php echo $stat ?></td>
					<td><?php echo appthemes_display_percentage( $stat, $sales['total'] ); ?></td>
				</tr>
			<?php } ?>
				<tr>
					<th colspan="3">Шлюзы</th>
				</tr>
			<?php foreach( APP_Gateway_Registry::get_gateways() as $id => $gateway ){
					$stat = ( isset( $sales['gateways'][ $id ] ) ) ? $sales['gateways'][ $id ] : 0;
			?>
				<tr>
					<td><?php echo $gateway->display_name( 'admin' ); ?></td>
					<td><?php echo $stat ?></td>
					<td><?php echo appthemes_display_percentage( $stat, $sales['total'] ); ?></td>
				</tr>
			<?php } ?>
				<tr>
					<td>Определились</td>
					<td><?php echo ( isset( $sales['gateways'][''] ) ) ? $sales['gateways'][''] : 0 ?></td>
					<td><?php echo appthemes_display_percentage( ( isset( $sales['gateways'][''] ) ) ? $sales['gateways'][''] : 0, $sales['total'] ); ?></td>
				</tr>
				<tr>
					<th colspan="3">Валюта</th>
				</tr>
				<?php foreach( APP_Currencies::get_currency_string_array() as $id => $string ){
					$stat = ( isset( $sales['currencies'][ $id ] ) ) ? $sales['currencies'][ $id ] : 0;
					if( $stat == 0 ) continue;
			?>
				<tr>
					<td><?php echo $string; ?></td>
					<td><?php echo $stat ?></td>
					<td><?php echo appthemes_display_percentage( $stat, $sales['total'] ); ?></td>
				</tr>
			<?php } ?>
			</tbody>
			<tfoot>
				<td colspan="3">
					<?php _e( 'Проценты могут не составлять 100%', 'appthemes-stats' ); ?>
				</td>
			</tfoot>
		</table>
		<?php
	}

	function income_box(){

		if( count( $this->items ) == 0 )
			return;

		$finished_orders = $this->stat->filterByStatus( array( 'tr_completed', 'tr_activated' ) );
		$unselected_orders = $this->stat->filterByGateway( '' );
		$unrealized_orders = $unselected_orders->filterByStatus( 'tr_pending' );

		$all = appthemes_count_all_posts( APPTHEMES_ORDER_PTYPE );

		$sales = array(
			'total' => count( $this->items ),
			'statuses' => $this->stat->countStatuses(),
			'gateways' => $this->stat->countGateways(),
			'currencies' => $this->stat->countCurrencies(),
			'finished' => $finished_orders->count(),
			'unselected' => $unselected_orders->count(),
			'unrealized' => $unrealized_orders->count(),
		);

		$income = array(
			'possible' => $this->stat->getTotalIncome(),
			'actual' => $finished_orders->getTotalIncome(),
			'unfinished' => $unselected_orders->getTotalIncome(),
			'unrealized' => $unrealized_orders->getTotalIncome(),
		);

		?>
		<table class="widefat" style="width: 25%; float: left; clear: none;">
			<tr>
					<th colspan="3">Доход</th>
				</tr>
				<tr>
					<td>Общий Возможный Доход</td>
					<td><?php $this->display_mixed_price( $income['possible'] ); ?></td>
					<td></td>
				</tr>
				<tr>
					<td>Фактические Доходы</td>
					<td><?php $this->display_mixed_price( $income['actual'] ); ?></td>
					<td></td>
				</tr>
				<tr>
					<td>Незавершенные Продажи</td>
					<td><?php echo $sales['unselected'] ?></td>
					<td><?php echo appthemes_display_percentage( $sales['unselected'], $sales['total'] ); ?></td>
				</tr>
				<tr>
					<td>Недостроенный Доход</td>
					<td><?php $this->display_mixed_price( $income['unfinished'] ); ?></td>
					<td></td>
				</tr>
				<tr>
					<td>Нереализованных Продаж</td>
					<td><?php echo $sales['unrealized'] ?></td>
					<td><?php echo appthemes_display_percentage( $sales['unrealized'], $sales['total'] ); ?></td>
				</tr>
				<tr>
					<td>Внереализационные Доходы</td>
					<td><?php $this->display_mixed_price( $income['unrealized'] ); ?></td>
					<td></td>
				</tr>
			</tbody>
			<tfoot>
				<td colspan="3">
					<?php _e( 'Проценты могут не составлять 100%', 'appthemes-stats' ); ?></br>
					<?php _e( 'Незавершенные продажи находятся на рассмотрении и шлюз не выбран.', 'appthemes-stats' ); ?></br>
					<?php _e( 'Нереализованные продажы шлюз, выбран, но не был завершен.', 'appthemes-stats' ); ?></br>
				</td>
			</tfoot>
		</table>
		<?php

	}

	// Provided for backwards comaptibility Vantage < 1.2
	function display_mixed_price( $mixed_prices ){

		if( current_theme_supports( 'app-price-format' ) )
			return appthemes_display_mixed_price( $mixed_prices );

		$strings = array();
		foreach( $mixed_prices as $currency => $amount ){
			$strings[] = APP_Currencies::get_price( $amount, $currency );
		}

		echo join( '</br>', $strings );

	}

	function extra_tablenav( $which ){

		if( $which == 'top' ){
			$this->months_dropdown( null );
			$this->gateways_dropdown();
			$this->statuses_dropdown();
			$this->currencies_dropdown();
			submit_button( __( 'Filter' ), 'button', false, false, array( 'id' => 'post-query-submit' ) );
		}

	}

	function months_dropdown( $post_type ) {

		$default = ( isset( $_GET['d'] ) ) ? $_GET['d'] : 90;

		$ranges = array(
			'1' => __( 'Последние 24 Часа', 'appthemes-stats' ),
			'7' => __( 'Последние 7 Дней', 'appthemes-stats' ),
			'30' => __( 'Последние 30 Дней', 'appthemes-stats' ),
			'90' => __( 'Последние 90 Дней', 'appthemes-stats' ),
			'180' => __( 'Последних 180 Дней', 'appthemes-stats' ),
			'365' => __( 'Последние 365 Дней', 'appthemes-stats' ),
		);

		$options = '';
		foreach( $ranges as $value => $string ){
			$args = array(
				'value' => $value
			);

			if( $default == $value )
				$args['selected'] = 'selected';

			$options .= html( 'option', $args, $string );
		}

		echo html( 'select', array( 'name' => 'd' ), $options );
	}

	function currencies_dropdown(){

		$default = ( isset( $_GET['c'] ) ) ? $_GET['c'] : '';

		$options = html( 'option', array( 'value' => '' ), __( 'Показать все валюты', 'appthemes-stats' ) );
		foreach( APP_Currencies::get_currency_string_array() as $code => $string ){
			$args = array(
				'value' => $code
			);

			if( $default == $code )
				$args['selected'] = 'selected';

			$options .= html( 'option', $args, $string );
		}

		echo html( 'select', array( 'name' => 'c' ), $options );
	}

	function gateways_dropdown(){

		$default = ( isset( $_GET['g'] ) ) ? $_GET['g'] : '';

		$options = html( 'option', array( 'value' => '' ), __( 'Показать все шлюзы', 'appthemes-stats' ) );
		foreach( APP_Gateway_Registry::get_gateways() as $gateway ){
			$args = array(
				'value' => $gateway->identifier()
			);

			if( $default == $gateway->identifier() )
				$args['selected'] = 'selected';

			$options .= html( 'option', $args, $gateway->display_name( 'admin' ) );
		}

		echo html( 'select', array( 'name' => 'g' ), $options );
	}

}
