<?php
/**
 * Functions that hook into WordPress to allow customizing the theme using the customizer.
 */

// @todo color chooser available after 1.x
add_action( 'customize_register', '_hrb_customize_color_scheme' );

add_action( 'customize_register', '_hrb_customize_listings' );
add_action( 'customize_register', '_hrb_customize_categories' );
add_action( 'customize_register', '_hrb_customize_header_nav' );
add_action( 'customize_register', '_hrb_customize_footer' );


### Hooks Callbacks

/**
 * Displays the theme color choices in the customizer.
 *
 * @since 1.0.0
 */
function _hrb_customize_color_scheme( $wp_customize ) {
	global $hrb_options;

	$wp_customize->add_setting( 'hrb_options[color]', array(
		'default' => $hrb_options->color,
		'type' => 'option'
	) );

	$wp_customize->add_control( 'hrb_color_scheme', array(
		'label'      => __( 'Color Scheme', APP_TD ),
		'section'    => 'colors',
		'settings'   => 'hrb_options[color]',
		'type'       => 'radio',
		'choices' => hrb_get_color_choices(),
	) );

	$default_colors = array(
		'primary_color'      => __( 'Primary Color (Links, Buttons)', APP_TD ),
		'accent_color'       => __( 'Accent Color (Main Navigation)', APP_TD ),
		'secondary_color'    => __( 'Secondary Color (Backgrounds)', APP_TD ),
		'footer_bg_color'    => __( 'Footer Background Color', APP_TD ),
		'footer_color'       => __( 'Footer Text Color', APP_TD ),
		'footer_links_color' => __( 'Footer Links Color', APP_TD ),
	);

	foreach ( $default_colors as $default_color => $label ) {
		$wp_customize->add_setting( "hrb_options[$default_color]", array(
			'default'           => $hrb_options->get_defaults( $default_color ),
			'sanitize_callback' => 'sanitize_hex_color',
			'type'              => 'option',
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, "hrb_options[$default_color]", array(
			'label'    => $label,
			'section'  => 'colors',
			'settings' => "hrb_options[$default_color]",
			'priority' => 11,
		) ) );
	}

}

/**
 * Displays the theme listing options in the customizer.
 *
 * @since 1.0.0
 */
function _hrb_customize_header_nav( $wp_customize ) {
	global $hrb_options;

	// Support for legacy header nav. Prior to 1.4.0.
	// Moved widget default content to index.php page content.
	// No longer need widget and these options.
	if ( ! is_active_sidebar( 'hrb-header-nav' ) )  {
		return;
	}

	$wp_customize->add_section( 'hrb_header', array(
		'title'       => __( 'Header', APP_TD ),
		'description' => __( 'Control the visibility of the optional custom header.', APP_TD ),
		'priority'    => 30,
	));

	$wp_customize->add_setting( 'hrb_options[custom_header_vis]', array(
		'title'   => '',
		'default' => 'yes',
		'type'    => 'option',
	));

	$wp_customize->add_control( 'hrb_extra_header', array(
		'label'    => __( 'Display Custom Header', APP_TD ),
		'section'  => 'hrb_header',
		'settings' => 'hrb_options[custom_header_vis]',
		'type'     => 'radio',
		'choices'  => array(
			'front'   => __( 'Front Page Only', APP_TD ),
			'any'     => __( 'Always', APP_TD ),
			'disable' => __( 'Disable', APP_TD ),
		),
	) );
}


/**
 * Displays the footer options in the customizer.
 * Appears under the "Site Identity" section.
 *
 * @since 1.4.0
 */
function _hrb_customize_footer( $wp_customize ) {
	global $hrb_options;

	// Add the footer copyright text setting.
	$wp_customize->add_setting( 'footer_copyright_text', array(
		'default' => '',
	) );

	// Add footer copyright text field.
	$wp_customize->add_control( 'footer_copyright_text', array(
		'label'    => __( 'Footer Copyright', APP_TD ),
		'type'     => 'text',
		'priority' => 20,
		'section'  => 'title_tagline',
	) );
}


/**
 * Displays the theme listing options in the customizer.
 *
 * @since 1.0.0
 */
function _hrb_customize_listings( $wp_customize ) {
	global $hrb_options;

	$wp_customize->add_section( 'hrb_listings', array(
		'title'    => __( 'Listings', APP_TD ),
		'priority' => 35,
	));

	$wp_customize->add_setting( 'hrb_options[projects_per_page]', array(
		'default' => $hrb_options->projects_per_page,
		'type'    => 'option',
	) );

	$wp_customize->add_setting( 'hrb_options[projects_frontpage]', array(
		'default' => $hrb_options->projects_frontpage,
		'type'    => 'option',
	) );

	$wp_customize->add_setting( 'hrb_options[users_per_page]', array(
		'default' => $hrb_options->users_per_page,
		'type'    => 'option',
	) );

	$wp_customize->add_setting( 'hrb_options[users_frontpage]', array(
		'default' => $hrb_options->users_frontpage,
		'type'    => 'option',
	) );

	$wp_customize->add_control( 'hrb_projects_frontpage', array(
		'label'      => __( 'Projects Front Page', APP_TD ),
		'section'    => 'hrb_listings',
		'settings'   => 'hrb_options[projects_frontpage]',
		'type'       => 'text',
	) );

	$wp_customize->add_control( 'hrb_projects_per_page', array(
		'label'      => __( 'Projects Per Page', APP_TD ),
		'section'    => 'hrb_listings',
		'settings'   => 'hrb_options[projects_per_page]',
		'type'       => 'text',
	) );

	$wp_customize->add_control( 'hrb_users_frontpage', array(
		'label'      => __( 'Users Front Page', APP_TD ),
		'section'    => 'hrb_listings',
		'settings'   => 'hrb_options[users_frontpage]',
		'type'       => 'text',
	) );

	$wp_customize->add_control( 'hrb_users_per_page', array(
		'label'      => __( 'Users Per Page', APP_TD ),
		'section'    => 'hrb_listings',
		'settings'   => 'hrb_options[users_per_page]',
		'type'       => 'text',
	) );
}

/**
 * Register the categories options.
 *
 * @since 1.0.0
 */
function _hrb_customize_categories( $wp_customize ) {
	categories_options( 'categories_dir', __( 'Categories Page Options', APP_TD ), $wp_customize );
	categories_options( 'categories_menu', __( 'Categories Menu Item Options', APP_TD ), $wp_customize );
}

### Helper functions

/**
 * Display categories related options in the customizer.
 *
 * @since 1.0.0
 */
function categories_options( $prefix, $title, $wp_customize ) {
	global $hrb_options;

	$wp_customize->add_section( 'hrb_'.$prefix.'_categories', array(
		'title'    => $title,
		'priority' => 999,
	));

	if ( 'categories_menu' == $prefix ) {

		$wp_customize->add_setting( 'hrb_options['.$prefix.'][show]', array(
			'default' => 'yes',
			'type'    => 'option',
		) );

		$wp_customize->add_control( 'hrb_'.$prefix.'_show', array(
				'label'      => __( 'Categories Menu Behavior', APP_TD ),
				'section'    => 'hrb_'.$prefix.'_categories',
				'settings'   => 'hrb_options['.$prefix.'][show]',
				'type'       => 'select',
				'choices' => array(
					'always' => __( 'Always Visible', APP_TD ),
					'click' => __( 'Visible on Click', APP_TD ),
					'' => __( 'Hide', APP_TD ),
				),
				'default' =>  'click',
			) );
	}

	$wp_customize->add_setting( 'hrb_options['.$prefix.'][count]', array(
		'default' => $hrb_options->projects_per_page,
		'type'    => 'option',
	) );

	$wp_customize->add_control( 'hrb_'.$prefix.'_count', array(
		'label'    => __( 'Count Listings in Category', APP_TD ),
		'section'  => 'hrb_'.$prefix.'_categories',
		'settings' => 'hrb_options['.$prefix.'][count]',
		'type'     => 'checkbox',
	) );

	$wp_customize->add_setting( 'hrb_options['.$prefix.'][hide_empty]', array(
		'default' => '',
		'type'    => 'option',
	) );

	$wp_customize->add_control( 'hrb_'.$prefix.'_hide_empty', array(
		'label'    => __( 'Hide Empty Categories', APP_TD ),
		'section'  => 'hrb_'.$prefix.'_categories',
		'settings' => 'hrb_options['.$prefix.'][hide_empty]',
		'type'     => 'checkbox',
	) );

	$wp_customize->add_setting( 'hrb_options['.$prefix.'][depth]', array(
		'default' => 1,
		'type'    => 'option',
	) );

	$wp_customize->add_control( 'hrb_'.$prefix.'_depth', array(
		'label'      => __( 'Category Depth', APP_TD ),
		'section'    => 'hrb_'.$prefix.'_categories',
		'settings'   => 'hrb_options['.$prefix.'][depth]',
		'type'       => 'select',
		'choices' => array(
			'999' => __( 'Show All', APP_TD ),
			'0' => '0',
			'1' => '1',
			'2' => '2',
			'3' => '3',
			'4' => '4',
			'5' => '5',
			'6' => '6',
			'7' => '7',
			'8' => '8',
			'9' => '9',
			'10' => '10',
		),
	) );

	$wp_customize->add_setting( 'hrb_options['.$prefix.'][sub_num]', array(
		'default' => $hrb_options->projects_per_page,
		'type'    => 'option',
	) );

	$wp_customize->add_control( 'hrb_'.$prefix.'_sub_num', array(
		'label'    => __( 'Number of Sub-Categories', APP_TD ),
		'section'  => 'hrb_'.$prefix.'_categories',
		'settings' => 'hrb_options['.$prefix.'][sub_num]',
		'type'     => 'select',
		'choices'  => array(
			'999' => __( 'Show All', APP_TD ),
			'0'   => '0',
			'1'   => '1',
			'2'   => '2',
			'3'   => '3',
			'4'   => '4',
			'5'   => '5',
			'6'   => '6',
			'7'   => '7',
			'8'   => '8',
			'9'   => '9',
			'10'  => '10',
		),
	) );
}

/**
 * Retrieves the theme available color choices.
 *
 * @uses apply_filters() Calls 'hrb_color_choices'
 *
 * @since 1.0.0
 */
function hrb_get_color_choices() {

	$color_choices = array(
		'modern' => __( 'Bee Modern (default)', APP_TD ),
		'green'  => __( 'Bee Green', APP_TD ),
		'water'  => __( 'Bee Water', APP_TD ),
		'urban'  => __( 'Bee Urban', APP_TD ),
		'dark'   => __( 'Bee Dark', APP_TD ),
		'custom' => __( 'Bee Custom', APP_TD ),
	);

	return apply_filters( 'hrb_color_choices', $color_choices );
}

/**
 * Enqueues front-end CSS for the custom color scheme.
 *
 * We can't use wp_enqueue_scripts & wp_add_inline_style b/c
 * this loads the custom css after style.css so it causes inheritance
 * bleed through on colors. Need to use wp_head instead to solve issue.
 * TwentySeventeen does the same thing.
 *
 * @since 1.5.0
 */
function hrb_color_scheme_css() {
	global $hrb_options;

	// Don't do anything if the current color is not custom.
	if ( 'custom' !== $hrb_options->color ) {
		return;
	}

	// Primary
	$hrb_primary_link_color = new APP_PHPColors( $hrb_options->primary_color ); /*!*/ // 75
	$hrb_primary_bg_hover_color = '#' . $hrb_primary_link_color->darken( 21 ); // -21
	$hrb_create_project_button_bg_color = '#' . $hrb_primary_link_color->darken( 11 ); // -11

	// Accent
	$hrb_primary_nav_bg_color = new APP_PHPColors( $hrb_options->accent_color ); /*!*/ //62

	$hrb_primary_border_color = '#' . $hrb_primary_nav_bg_color->darken( 11 ); // -11
	$hrb_primary_nav_hover_color = '#' . $hrb_primary_nav_bg_color->darken( 6 ); // -6

	// Secondary
	$hrb_highlight_bg_color = new APP_PHPColors( $hrb_options->secondary_color ); /*!*/ // 17

	$hrb_highlight_btn_bg_color = '#' . $hrb_highlight_bg_color->darken( -8 ); // +8
	$hrb_single_project_header_bg_color = '#' . $hrb_highlight_bg_color->darken( 3 ); // -3
	$hrb_featured_title_hover_color = '#' . $hrb_highlight_bg_color->darken( 4 ); // -4
	$hrb_featured_border_color = '#' . $hrb_highlight_bg_color->darken( -6 ); // +6
	$hrb_featured_meta_below_desc_color = '#' . $hrb_highlight_bg_color->darken( -23 ); // +23
	$hrb_featured_label_bg_color = '#' . $hrb_highlight_bg_color->darken( -15 ); // +15
	$hrb_project_icon_color = "#ABA8B8";
	$hrb_featured_meta_color = "#C6DFD8";
	$hrb_highlight_color = "#FFF";
	$hrb_top_bar_bg_color = "#FFF";
	$hrb_featured_label_color = "#F0EFF4";
	$hrb_progtrckr_bottom_border_color = "#DEE5EE";
	$hrb_secondary_bg_color = "#E0E4EE";
	$hrb_pagination_link_bg_color = "#E6E8EA";
	$hrb_project_title_color = "#415157";
	$hrb_progtrckr_text_color = "#445159";
	$hrb_pagination_link_color = "#000";
	$hrb_freelancers_header_title_bg_color = $hrb_primary_nav_bg_color;
	$hrb_budget_deadline_time_left_bg_color = new APP_PHPColors( $hrb_freelancers_header_title_bg_color );
	$hrb_budget_deadline_time_bg_color = "#" . $hrb_budget_deadline_time_left_bg_color->darken( 8 ); // -8
	$hrb_single_project_bid_btn_bg_color = "#FB6B5B";
	$hrb_single_project_bid_btn_hover_bg_color = "#C95B4F";
	$hrb_footer_bg_color = new APP_PHPColors( $hrb_options->footer_bg_color );
	$hrb_footer_text_color = $hrb_options->footer_color;
	$hrb_footer_link_color = $hrb_options->footer_links_color;
	$hrb_footer_border_color = "#" . $hrb_footer_bg_color->foreground();

	$css = "
		/* HireBee Custom Color Scheme */
		:root {
			/* Primary Color: Buttons, Links */
			--hrb--primary-bg-hover-color: {$hrb_primary_bg_hover_color};
			--hrb--primary-link-color: {$hrb_primary_link_color};
			--hrb--article-link-color: var(--hrb--primary-link-color);
			--hrb--primary-bg-color: var(--hrb--primary-link-color);
			--hrb--single-by-widget-meta-color: var(--hrb--primary-link-color);
			--hrb--comment-form-log-out-bg-color: var(--hrb--primary-link-color);
			--hrb--pagination-home-link-bg-color: var(--hrb--primary-link-color);
			--hrb--pagination-link-hover-bg-color: var(--hrb--primary-link-color);
			--hrb--budget-deadline-bg-color: var(--hrb--primary-link-color);
			--hrb--create-project-button-bg-color: {$hrb_create_project_button_bg_color};
			--hrb--budget-deadline-type-bg-color: var(--hrb--create-project-button-bg-color);
			--hrb--featured-link-color: var(--hrb--primary-link-color);

			/* Accent: Naviagation */
			--hrb--primary-border-color: {$hrb_primary_border_color};
			--hrb--primary-nav-bg-color: {$hrb_primary_nav_bg_color};
			--hrb--primary-nav-hover-color: {$hrb_primary_nav_hover_color};
			--hrb--register-box-bg-color: var(--hrb--primary-nav-bg-color);
			--hrb--progtrckr-color: var(--hrb--primary-nav-bg-color);


			/* Complement Color: Backgrounds */
			--hrb--single-project-header-bg-color: {$hrb_single_project_header_bg_color};
			--hrb--highlight-bg-color: {$hrb_highlight_bg_color};
			--hrb--post-date-box-border-color: var(--hrb--highlight-bg-color);
			--hrb--primary-nav-toggle-color: var(--hrb--highlight-bg-color);
			--hrb--search-btn-bg-hover-color: var(--hrb--highlight-bg-color);
			--hrb--highlight-btn-hover-bg-color: var(--hrb--highlight-bg-color);
			--hrb--single-bid-terms-bg-color: var(--hrb--highlight-bg-color);
			--hrb--featured-meta-bg-color: var(--hrb--highlight-bg-color);
			--hrb--create-project-selected-currency-bg-color: var(--hrb--highlight-bg-color);
			--hrb--dashboard-new-notification-color: var(--hrb--highlight-bg-color);
			--hrb--comment-form-logged-in-as-bg-color: var(--hrb--highlight-bg-color);
			--hrb--tab-active-bg-color: var(--hrb--highlight-bg-color);
			--hrb--highlight-btn-bg-color: {$hrb_highlight_btn_bg_color};
			--hrb--post-date-box-bg-color: var(--hrb--highlight-btn-bg-color);
			--hrb--search-btn-bg-color: var(--hrb--highlight-btn-bg-color);
			--hrb--dashboard-title-icon-color: var(--hrb--highlight-btn-bg-color);
			--hrb--top-widgets-bg-color: var(--hrb--highlight-btn-bg-color);
			--hrb--featured-title-color: var(--hrb--highlight-btn-bg-color);
			--hrb--form-header-bg-color: var(--hrb--highlight-btn-bg-color);
			--hrb--featured-title-hover-color: {$hrb_featured_title_hover_color};
			--hrb--featured-border-color: {$hrb_featured_border_color};
			--hrb--featured-meta-below-desc-color: {$hrb_featured_meta_below_desc_color};
			--hrb--featured-meta-below-desc-link-color: var(--hrb--featured-meta-below-desc-color);
			--hrb--featured-label-bg-color: {$hrb_featured_label_bg_color};
			--hrb--project-icon-color: {$hrb_project_icon_color};
			--hrb--featured-meta-color: {$hrb_featured_meta_color};

			/* Other Colors */
			--hrb--highlight-color: {$hrb_highlight_color};
			--hrb--top-bar-bg-color: {$hrb_top_bar_bg_color};
			--hrb--top-widgets-color: var(--hrb--highlight-color);
			--hrb--featured-label-color: {$hrb_featured_label_color};
			--hrb--progtrckr-bottom-border-color: {$hrb_progtrckr_bottom_border_color};
			--hrb--secondary-bg-color: {$hrb_secondary_bg_color};
			--hrb--pagination-link-bg-color: {$hrb_pagination_link_bg_color};
			--hrb--project-title-color: {$hrb_project_title_color};
			--hrb--progtrckr-text-color: {$hrb_progtrckr_text_color};
			--hrb--pagination-link-color: {$hrb_pagination_link_color};

			--hrb--budget-deadline-time-bg-color: {$hrb_budget_deadline_time_bg_color};
			--hrb--budget-deadline-time-left-bg-color: {$hrb_budget_deadline_time_left_bg_color};
			--hrb--freelancers-header-title-bg-color: {$hrb_freelancers_header_title_bg_color};

			--hrb--single-project-bid-btn-bg-color: {$hrb_single_project_bid_btn_bg_color};
			--hrb--single-project-bid-btn-hover-bg-color: {$hrb_single_project_bid_btn_hover_bg_color};

			/* Footer */
			--hrb--footer-bg-color: {$hrb_footer_bg_color};
			--hrb--footer-text-color: {$hrb_footer_text_color};
			--hrb--footer-link-color: {$hrb_footer_link_color};
			--hrb--footer-border-color: {$hrb_footer_border_color};
		}
	";
?>
<style type="text/css" id="custom-theme-colors">
	<?php
	/**
	 * Filters custom color CSS.
	 *
	 * @since 1.5.0
	 *
	 * @param $css string Custom theme color CSS.
	 */
	echo apply_filters( 'hrb_custom_colors_css', $css );
	?>
</style>
<?php
}
// Priority is very important! Above 7 equals css inheritance issues.
// Although maybe this is not critical for HireBee?
add_action( 'wp_head', 'hrb_color_scheme_css', 7 );
