<?php
/**
 * Wallet One Extra Currencies.
 *
 * @package DKF\WalletOne
 */

defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

/**
 * Wallet One Payment Methods class.
 */
class DKF_WalletOne_Currencies {

	/**
	 * Registers extra currencies and add additional parameters to existing.
	 */
	public static function init() {

		foreach ( self::get_supported() as $code => $args ) {

			if ( $exists = APP_Currencies::get_currency( $code ) ) {
				$args = array_merge( $exists, $args );
			}

			APP_Currencies::update_currency( $code, $args );
		}

	}

	/**
	 * Retrieves currency numeric code by given ISO code.
	 *
	 * @param string $code ISO code.
	 *
	 * @return int Numeric code.
	 */
	public static function get_num_code( $code ) {
		$currency = APP_Currencies::get_currency( $code );
		$num_code = isset( $currency['number'] ) ? $currency['number'] : 0;
		// TODO: Display notice about unsupported currency.
		return $num_code;
	}

	public static function get_supported() {
		return array(
			'USD' => array(
				'number' => 840,
			),
			'RUB' => array(
				'symbol' => '&#8381;',
				'number' => 643,
			),
			'UAH' => array(
				'symbol' => '&#8372;',
				'name'   => __( 'Ukrainian Hryvnia', DKF_W1_TD ),
				'number' => 980,
			),
			'KZT' => array(
				'symbol' => '&#8376;',
				'name'   => __( 'Kazakhstani Tenge', DKF_W1_TD ),
				'number' => 398,
			),
			'BYR' => array(
				'symbol' => 'Br',
				'name'   => __( 'Belarusian Rubles', DKF_W1_TD ),
				'number' => 974,
			),
			'EUR' => array(
				'number' => 978,
			),
			'TJS' => array(
				'symbol' => 'C',
				'name'   => __( 'Tajik Somoni', DKF_W1_TD ),
				'number' => 972,
			),
			'ZAR' => array(
				'symbol' => 'R',
				'name'   => __( 'South African Rand', DKF_W1_TD ),
				'number' => 710,
			),
			'PLN' => array(
				'number' => 985,
			),
			'GEL' => array(
				'symbol' => '&#4314;',
				'name'   => __( 'Georgian lari', DKF_W1_TD ),
				'number' => 981,
			),
		);
	}

}
